==> cdktf-cdktf-provider-gitlab-6.0.1.tar.gz: package/docs/API.csharp.md <==
# Submodules <a name="Submodules" id="submodules"></a>

The following submodules are available:
- [applicationSettings](./applicationSettings.csharp.md)
- [branch](./branch.csharp.md)
- [branchProtection](./branchProtection.csharp.md)
- [clusterAgent](./clusterAgent.csharp.md)
- [clusterAgentToken](./clusterAgentToken.csharp.md)
- [dataGitlabBranch](./dataGitlabBranch.csharp.md)
- [dataGitlabClusterAgent](./dataGitlabClusterAgent.csharp.md)
- [dataGitlabClusterAgents](./dataGitlabClusterAgents.csharp.md)
- [dataGitlabCurrentUser](./dataGitlabCurrentUser.csharp.md)
- [dataGitlabGroup](./dataGitlabGroup.csharp.md)
- [dataGitlabGroupHook](./dataGitlabGroupHook.csharp.md)
- [dataGitlabGroupHooks](./dataGitlabGroupHooks.csharp.md)
- [dataGitlabGroupMembership](./dataGitlabGroupMembership.csharp.md)
- [dataGitlabGroupSubgroups](./dataGitlabGroupSubgroups.csharp.md)
- [dataGitlabGroupVariable](./dataGitlabGroupVariable.csharp.md)
- [dataGitlabGroupVariables](./dataGitlabGroupVariables.csharp.md)
- [dataGitlabGroups](./dataGitlabGroups.csharp.md)
- [dataGitlabInstanceDeployKeys](./dataGitlabInstanceDeployKeys.csharp.md)
- [dataGitlabInstanceVariable](./dataGitlabInstanceVariable.csharp.md)
- [dataGitlabInstanceVariables](./dataGitlabInstanceVariables.csharp.md)
- [dataGitlabMetadata](./dataGitlabMetadata.csharp.md)
- [dataGitlabProject](./dataGitlabProject.csharp.md)
- [dataGitlabProjectBranches](./dataGitlabProjectBranches.csharp.md)
- [dataGitlabProjectHook](./dataGitlabProjectHook.csharp.md)
- [dataGitlabProjectHooks](./dataGitlabProjectHooks.csharp.md)
- [dataGitlabProjectIssue](./dataGitlabProjectIssue.csharp.md)
- [dataGitlabProjectIssues](./dataGitlabProjectIssues.csharp.md)
- [dataGitlabProjectMembership](./dataGitlabProjectMembership.csharp.md)
- [dataGitlabProjectMilestone](./dataGitlabProjectMilestone.csharp.md)
- [dataGitlabProjectMilestones](./dataGitlabProjectMilestones.csharp.md)
- [dataGitlabProjectProtectedBranch](./dataGitlabProjectProtectedBranch.csharp.md)
- [dataGitlabProjectProtectedBranches](./dataGitlabProjectProtectedBranches.csharp.md)
- [dataGitlabProjectTag](./dataGitlabProjectTag.csharp.md)
- [dataGitlabProjectTags](./dataGitlabProjectTags.csharp.md)
- [dataGitlabProjectVariable](./dataGitlabProjectVariable.csharp.md)
- [dataGitlabProjectVariables](./dataGitlabProjectVariables.csharp.md)
- [dataGitlabProjects](./dataGitlabProjects.csharp.md)
- [dataGitlabReleaseLink](./dataGitlabReleaseLink.csharp.md)
- [dataGitlabReleaseLinks](./dataGitlabReleaseLinks.csharp.md)
- [dataGitlabRepositoryFile](./dataGitlabRepositoryFile.csharp.md)
- [dataGitlabRepositoryTree](./dataGitlabRepositoryTree.csharp.md)
- [dataGitlabUser](./dataGitlabUser.csharp.md)
- [dataGitlabUserSshkeys](./dataGitlabUserSshkeys.csharp.md)
- [dataGitlabUsers](./dataGitlabUsers.csharp.md)
- [deployKey](./deployKey.csharp.md)
- [deployKeyEnable](./deployKeyEnable.csharp.md)
- [deployToken](./deployToken.csharp.md)
- [group](./group.csharp.md)
- [groupAccessToken](./groupAccessToken.csharp.md)
- [groupBadge](./groupBadge.csharp.md)
- [groupCluster](./groupCluster.csharp.md)
- [groupCustomAttribute](./groupCustomAttribute.csharp.md)
- [groupHook](./groupHook.csharp.md)
- [groupLabel](./groupLabel.csharp.md)
- [groupLdapLink](./groupLdapLink.csharp.md)
- [groupMembership](./groupMembership.csharp.md)
- [groupProjectFileTemplate](./groupProjectFileTemplate.csharp.md)
- [groupSamlLink](./groupSamlLink.csharp.md)
- [groupShareGroup](./groupShareGroup.csharp.md)
- [groupVariable](./groupVariable.csharp.md)
- [instanceCluster](./instanceCluster.csharp.md)
- [instanceVariable](./instanceVariable.csharp.md)
- [label](./label.csharp.md)
- [managedLicense](./managedLicense.csharp.md)
- [pagesDomain](./pagesDomain.csharp.md)
- [personalAccessToken](./personalAccessToken.csharp.md)
- [pipelineSchedule](./pipelineSchedule.csharp.md)
- [pipelineScheduleVariable](./pipelineScheduleVariable.csharp.md)
- [pipelineTrigger](./pipelineTrigger.csharp.md)
- [project](./project.csharp.md)
- [projectAccessToken](./projectAccessToken.csharp.md)
- [projectApprovalRule](./projectApprovalRule.csharp.md)
- [projectBadge](./projectBadge.csharp.md)
- [projectCluster](./projectCluster.csharp.md)
- [projectCustomAttribute](./projectCustomAttribute.csharp.md)
- [projectEnvironment](./projectEnvironment.csharp.md)
- [projectFreezePeriod](./projectFreezePeriod.csharp.md)
- [projectHook](./projectHook.csharp.md)
- [projectIssue](./projectIssue.csharp.md)
- [projectIssueBoard](./projectIssueBoard.csharp.md)
- [projectLevelMrApprovals](./projectLevelMrApprovals.csharp.md)
- [projectMembership](./projectMembership.csharp.md)
- [projectMilestone](./projectMilestone.csharp.md)
- [projectMirror](./projectMirror.csharp.md)
- [projectProtectedEnvironment](./projectProtectedEnvironment.csharp.md)
- [projectRunnerEnablement](./projectRunnerEnablement.csharp.md)
- [projectShareGroup](./projectShareGroup.csharp.md)
- [projectTag](./projectTag.csharp.md)
- [projectVariable](./projectVariable.csharp.md)
- [provider](./provider.csharp.md)
- [releaseLink](./releaseLink.csharp.md)
- [repositoryFile](./repositoryFile.csharp.md)
- [runner](./runner.csharp.md)
- [serviceEmailsOnPush](./serviceEmailsOnPush.csharp.md)
- [serviceExternalWiki](./serviceExternalWiki.csharp.md)
- [serviceGithub](./serviceGithub.csharp.md)
- [serviceJira](./serviceJira.csharp.md)
- [serviceMicrosoftTeams](./serviceMicrosoftTeams.csharp.md)
- [servicePipelinesEmail](./servicePipelinesEmail.csharp.md)
- [serviceSlack](./serviceSlack.csharp.md)
- [systemHook](./systemHook.csharp.md)
- [tagProtection](./tagProtection.csharp.md)
- [topic](./topic.csharp.md)
- [user](./user.csharp.md)
- [userCustomAttribute](./userCustomAttribute.csharp.md)
- [userGpgkey](./userGpgkey.csharp.md)
- [userSshkey](./userSshkey.csharp.md)

==> cdktf-cdktf-provider-gitlab-6.0.2.tar.gz: package/docs/API.csharp.md <==
# Submodules <a name="Submodules" id="submodules"></a>

The following submodules are available:
- [application](./application.csharp.md)
- [applicationSettings](./applicationSettings.csharp.md)
- [branch](./branch.csharp.md)
- [branchProtection](./branchProtection.csharp.md)
- [clusterAgent](./clusterAgent.csharp.md)
- [clusterAgentToken](./clusterAgentToken.csharp.md)
- [dataGitlabApplication](./dataGitlabApplication.csharp.md)
- [dataGitlabBranch](./dataGitlabBranch.csharp.md)
- [dataGitlabClusterAgent](./dataGitlabClusterAgent.csharp.md)
- [dataGitlabClusterAgents](./dataGitlabClusterAgents.csharp.md)
- [dataGitlabCurrentUser](./dataGitlabCurrentUser.csharp.md)
- [dataGitlabGroup](./dataGitlabGroup.csharp.md)
- [dataGitlabGroupHook](./dataGitlabGroupHook.csharp.md)
- [dataGitlabGroupHooks](./dataGitlabGroupHooks.csharp.md)
- [dataGitlabGroupMembership](./dataGitlabGroupMembership.csharp.md)
- [dataGitlabGroupSubgroups](./dataGitlabGroupSubgroups.csharp.md)
- [dataGitlabGroupVariable](./dataGitlabGroupVariable.csharp.md)
- [dataGitlabGroupVariables](./dataGitlabGroupVariables.csharp.md)
- [dataGitlabGroups](./dataGitlabGroups.csharp.md)
- [dataGitlabInstanceDeployKeys](./dataGitlabInstanceDeployKeys.csharp.md)
- [dataGitlabInstanceVariable](./dataGitlabInstanceVariable.csharp.md)
- [dataGitlabInstanceVariables](./dataGitlabInstanceVariables.csharp.md)
- [dataGitlabMetadata](./dataGitlabMetadata.csharp.md)
- [dataGitlabProject](./dataGitlabProject.csharp.md)
- [dataGitlabProjectBranches](./dataGitlabProjectBranches.csharp.md)
- [dataGitlabProjectHook](./dataGitlabProjectHook.csharp.md)
- [dataGitlabProjectHooks](./dataGitlabProjectHooks.csharp.md)
- [dataGitlabProjectIssue](./dataGitlabProjectIssue.csharp.md)
- [dataGitlabProjectIssues](./dataGitlabProjectIssues.csharp.md)
- [dataGitlabProjectMembership](./dataGitlabProjectMembership.csharp.md)
- [dataGitlabProjectMilestone](./dataGitlabProjectMilestone.csharp.md)
- [dataGitlabProjectMilestones](./dataGitlabProjectMilestones.csharp.md)
- [dataGitlabProjectProtectedBranch](./dataGitlabProjectProtectedBranch.csharp.md)
- [dataGitlabProjectProtectedBranches](./dataGitlabProjectProtectedBranches.csharp.md)
- [dataGitlabProjectTag](./dataGitlabProjectTag.csharp.md)
- [dataGitlabProjectTags](./dataGitlabProjectTags.csharp.md)
- [dataGitlabProjectVariable](./dataGitlabProjectVariable.csharp.md)
- [dataGitlabProjectVariables](./dataGitlabProjectVariables.csharp.md)
- [dataGitlabProjects](./dataGitlabProjects.csharp.md)
- [dataGitlabReleaseLink](./dataGitlabReleaseLink.csharp.md)
- [dataGitlabReleaseLinks](./dataGitlabReleaseLinks.csharp.md)
- [dataGitlabRepositoryFile](./dataGitlabRepositoryFile.csharp.md)
- [dataGitlabRepositoryTree](./dataGitlabRepositoryTree.csharp.md)
- [dataGitlabUser](./dataGitlabUser.csharp.md)
- [dataGitlabUserSshkeys](./dataGitlabUserSshkeys.csharp.md)
- [dataGitlabUsers](./dataGitlabUsers.csharp.md)
- [deployKey](./deployKey.csharp.md)
- [deployKeyEnable](./deployKeyEnable.csharp.md)
- [deployToken](./deployToken.csharp.md)
- [group](./group.csharp.md)
- [groupAccessToken](./groupAccessToken.csharp.md)
- [groupBadge](./groupBadge.csharp.md)
- [groupCluster](./groupCluster.csharp.md)
- [groupCustomAttribute](./groupCustomAttribute.csharp.md)
- [groupHook](./groupHook.csharp.md)
- [groupLabel](./groupLabel.csharp.md)
- [groupLdapLink](./groupLdapLink.csharp.md)
- [groupMembership](./groupMembership.csharp.md)
- [groupProjectFileTemplate](./groupProjectFileTemplate.csharp.md)
- [groupSamlLink](./groupSamlLink.csharp.md)
- [groupShareGroup](./groupShareGroup.csharp.md)
- [groupVariable](./groupVariable.csharp.md)
- [instanceCluster](./instanceCluster.csharp.md)
- [instanceVariable](./instanceVariable.csharp.md)
- [label](./label.csharp.md)
- [managedLicense](./managedLicense.csharp.md)
- [pagesDomain](./pagesDomain.csharp.md)
- [personalAccessToken](./personalAccessToken.csharp.md)
- [pipelineSchedule](./pipelineSchedule.csharp.md)
- [pipelineScheduleVariable](./pipelineScheduleVariable.csharp.md)
- [pipelineTrigger](./pipelineTrigger.csharp.md)
- [project](./project.csharp.md)
- [projectAccessToken](./projectAccessToken.csharp.md)
- [projectApprovalRule](./projectApprovalRule.csharp.md)
- [projectBadge](./projectBadge.csharp.md)
- [projectCluster](./projectCluster.csharp.md)
- [projectCustomAttribute](./projectCustomAttribute.csharp.md)
- [projectEnvironment](./projectEnvironment.csharp.md)
- [projectFreezePeriod](./projectFreezePeriod.csharp.md)
- [projectHook](./projectHook.csharp.md)
- [projectIssue](./projectIssue.csharp.md)
- [projectIssueBoard](./projectIssueBoard.csharp.md)
- [projectLevelMrApprovals](./projectLevelMrApprovals.csharp.md)
- [projectMembership](./projectMembership.csharp.md)
- [projectMilestone](./projectMilestone.csharp.md)
- [projectMirror](./projectMirror.csharp.md)
- [projectProtectedEnvironment](./projectProtectedEnvironment.csharp.md)
- [projectRunnerEnablement](./projectRunnerEnablement.csharp.md)
- [projectShareGroup](./projectShareGroup.csharp.md)
- [projectTag](./projectTag.csharp.md)
- [projectVariable](./projectVariable.csharp.md)
- [provider](./provider.csharp.md)
- [releaseLink](./releaseLink.csharp.md)
- [repositoryFile](./repositoryFile.csharp.md)
- [runner](./runner.csharp.md)
- [serviceCustomIssueTracker](./serviceCustomIssueTracker.csharp.md)
- [serviceEmailsOnPush](./serviceEmailsOnPush.csharp.md)
- [serviceExternalWiki](./serviceExternalWiki.csharp.md)
- [serviceGithub](./serviceGithub.csharp.md)
- [serviceJira](./serviceJira.csharp.md)
- [serviceMicrosoftTeams](./serviceMicrosoftTeams.csharp.md)
- [servicePipelinesEmail](./servicePipelinesEmail.csharp.md)
- [serviceSlack](./serviceSlack.csharp.md)
- [systemHook](./systemHook.csharp.md)
- [tagProtection](./tagProtection.csharp.md)
- [topic](./topic.csharp.md)
- [user](./user.csharp.md)
- [userCustomAttribute](./userCustomAttribute.csharp.md)
- [userGpgkey](./userGpgkey.csharp.md)
- [userSshkey](./userSshkey.csharp.md)
